@@ -6,6 +6,7 @@ import os
 
 from pyf.dataflow.core import component, BYPASS_VALS
 from pyf.componentized.components.writer import BaseFileWriter
+from pyf.componentized.configuration.keys import SimpleKey
 
 def buftee(iterable, n=2):
     """ An itertools.tee clone that also returns the internal buffers """
@@ -25,6 +26,9 @@ def buftee(iterable, n=2):
     return tuple([(gen(d), d) for d in deques])
 
 class MultipleFileWriter(BaseFileWriter):
+    configuration = [SimpleKey('splitkey',
+                               label="Split Attribute (optionnal)",
+                               help_text="Attribute with which to split files"),]
     outputs_files = True
     
     def __init__(self, config_node, name):
@@ -34,7 +38,7 @@ class MultipleFileWriter(BaseFileWriter):
         
     def initialize(self):
         self.key_getter_node = self.get_config_key_node('splitkey')
-        if self.key_getter_node is not None:
+        if self.key_getter_node is not None and self.key_getter_node.text is not None:
             key_type = self.key_getter_node.get('type', 'attribute')
             key_content = self.key_getter_node.text.strip()
             
@@ -65,8 +69,9 @@ class MultipleFileWriter(BaseFileWriter):
             else:
                 yield Ellipsis
 
-    def init_filename(self, key):
+    def init_filename(self, key, sample_item=None):
         output_filename = self.prepare_filename(self.get_config_key('target_filename'),
+                                                sample_item=sample_item,
                                                 key=key)
         filename = self.get_output_filename(output_filename)
         return output_filename, filename
@@ -87,19 +92,20 @@ class MultipleFileWriter(BaseFileWriter):
                     
                     self.add_key_writer(key_result,
                                         other_values,
-                                        otherqueue)
+                                        otherqueue,
+                                        sample_item=item)
                     
                 yield True
                 
             except StopIteration:
                 break
             
-    def add_key_writer(self, key, flow, tee_buffer):
+    def add_key_writer(self, key, flow, tee_buffer, sample_item=None):
         input_buffer = collections.deque()
         
         in_flow = self.prepare_input_flow(flow, input_buffer)
         
-        output_filename, temp_filename = self.init_filename(key)
+        output_filename, temp_filename = self.init_filename(key, sample_item=sample_item)
         
         iterator = self.write(in_flow,
                               key,
